==> dl.php?src=linea21_2_0_0.zip: linea21/newsletter/help.php <==
<?php
/**
 * Newsletter module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\newsletter
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('news')) ReloadIndex('admin');
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>

<div id="aide"><?php if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','add');?></p>
<ul>
	<li><?php echo _t('newsletter','help_add1');?></li>
	<li><?php echo _t('newsletter','help_add2');?></li>
	<li><?php echo _t('newsletter','help_add3');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','det');?></p>
<ul>
	<li><?php echo _t('newsletter','help_det1');?></li>
	<li><?php echo _t('newsletter','help_det2');?></li>
</ul>
      <?php
  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','mod');?></p>
<ul>
	<li><?php echo _t('newsletter','help_mod1');?></li>
	<li><?php echo _t('newsletter','help_mod2');?></li>
	<li><?php echo _t('newsletter','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','list');?></p>
<ul>
	<li><?php echo _t('newsletter','help_list1');?></li>
	<li><?php echo _t('newsletter','help_list2');?></li>
	<li><?php echo _t('newsletter','help_list3');?></li>
	<li><?php echo _t('newsletter','help_list4');?></li>
	<li><?php echo _t('newsletter','help_list5');?></li>
</ul>
      <?php }
      if ($todo == 'sup') {
        ?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','sup');?></p>
<ul>
	<li><?php echo _t('newsletter','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->

==> dl.php?src=linea21_2_8_0.zip: linea21/newsletter/help.php <==
<?php
/**
 * Newsletter module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\newsletter
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('news')) ReloadIndex('admin');
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="fa fa-life-ring" aria-hidden="true"></i> <?php echo _t('help','title');?></a>

<div id="aide"><?php if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','add');?></p>
<ul>
	<li><?php echo _t('newsletter','help_add1');?></li>
	<li><?php echo _t('newsletter','help_add2');?></li>
	<li><?php echo _t('newsletter','help_add3');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','det');?></p>
<ul>
	<li><?php echo _t('newsletter','help_det1');?></li>
	<li><?php echo _t('newsletter','help_det2');?></li>
</ul>
      <?php
  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','mod');?></p>
<ul>
	<li><?php echo _t('newsletter','help_mod1');?></li>
	<li><?php echo _t('newsletter','help_mod2');?></li>
	<li><?php echo _t('newsletter','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','list');?></p>
<ul>
	<li><?php echo _t('newsletter','help_list1');?></li>
	<li><?php echo _t('newsletter','help_list2');?></li>
	<li><?php echo _t('newsletter','help_list3');?></li>
	<li><?php echo _t('newsletter','help_list4');?></li>
	<li><?php echo _t('newsletter','help_list5');?></li>
</ul>
      <?php }
      if ($todo == 'sup') {
        ?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('newsletter','sup');?></p>
<ul>
	<li><?php echo _t('newsletter','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->
